@@ -1,6 +1,8 @@
 package MyPhrasebook;
 
+use strict;
+use warnings;
+
 use base qw( Data::Phrasebook );
 
 1;
-
